﻿// ----------------------------------------------------------------------------
// <copyright company="F.C. Soft., Inc.">
//   Copyright(c) F.C. Soft., Inc.  All rights reserved.
// </copyright>
// <license>
//   Licensed to F.C. Soft., Inc. (FCSoft) under one or more contributor
//   license agreements.  See the NOTICE file distributed with this work for
//   additional information regarding copyright ownership.  FCSoft licenses
//   this file to You under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.  You
//   may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
// </license>
// ----------------------------------------------------------------------------
namespace FCSoft.SilverFrost.Framework
{
    /// <summary>
    /// 配列に関するユーティリティクラスです。
    /// </summary>
    public static class ArrayUtility
    {
        /// <summary>
        /// <see cref="byte"/> の配列を比較します。
        /// </summary>
        /// <param name="array1">配列1。</param>
        /// <param name="offset1">比較を開始する <paramref name="array1"/> の開始位置。</param>
        /// <param name="array2">配列2。</param>
        /// <param name="offset2">比較を開始する <paramref name="array2"/> の開始位置。</param>
        /// <param name="length">比較する要素数。</param>
        /// <returns>
        /// <paramref name="array1"/> と <paramref name="array2"/> が共に <see langword="null"/>
        /// または、共に指定した範囲の要素が存在し、同じ場合は <see langword="true"/>。
        /// それ以外の場合は <see langword="false"/>。
        /// </returns>
        public static bool Equals(byte[] array1, int offset1, byte[] array2, int offset2, int length)
        {
            if (array1 == null)
            {
                return array2 == null;
            }

            if (array2 == null
                || offset1 + length > array1.Length
                || offset2 + length > array2.Length)
            {
                return false;
            }

            while (length > 0)
            {
                if (array1[offset1] != array2[offset2])
                {
                    return false;
                }

                offset1++;
                offset2++;
                length--;
            }

            return true;
        }
    }
}